==> filemv0.472.zip: source/winpaint.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <windows.h>

#include "main.h"
#include "mode.h"
#include "initial.h"
#include "paintflag.h"
#include "winpaint.h"
#include "tab.h"

#define resize() SendMessage(hmainwnd,WM_SIZE,0,0);


void winp::BitBlt(HDC hdc, HDC mem, int wx, int wy)
{
	wx = (wx==0) ? insideX : wx;
	wy = (wy==0) ? insideY : wy;
	pX =0; pY =0;
	pW =wx; pH =wy+status_h;
	memX =0;//oX;
	memY =0;//oY;

	if(ntab ==tab_r || mode==W_MODE_EDITONLY) 
	{
		pX =diredit_l;
	}
	else 
	{
		pX =xL +buttonx/2;
	}
	::BitBlt(hdc, pX,pY,pW,pH, mem, memX, memY, SRCCOPY);
}

void winp::set(HWND dr,HWND dl,HWND der, HWND del, HWND u, HWND d, HWND ed)
{
	hDir =dr;
	hDirL =dl;
	hDirEdit =der;
	hDirEditL =del;
	hUp =u;
	hDown =d;
	hEdit =ed;
}

#define windf(hW, x, y, wx, wy) DeferWindowPos(hDwp, hW, HWND_TOP, x, y, wx, wy, SWP_SHOWWINDOW)

void winp::mvWins()
{
    HDWP hDwp;
    hDwp = BeginDeferWindowPos(9);
    hDwp = windf( hDirL, xL -dir_w, dir_ueh, dir_w, dirL_h );
    hDwp = windf( hDir, xL , dir_ueh, dir_w, dirR_h );
    hDwp = windf( hDirEditL, diredit_l, dir_ueh, xL -dir_w, dirL_h);
    hDwp = windf( hDirEdit, xL +dir_w, dir_ueh, xR -dir_w, dirR_h);
    hDwp = windf( hListL, diredit_l, listtop, xL -buttonx/2, listLy);
    hDwp = windf( hList, xL +buttonx/2, listtop, xR - buttonx/2, listRy );
    hDwp = windf( hUp, xL -buttonx/2, listtop +listy/2 -25, buttonx, buttony);
    hDwp = windf( hDown, xL -buttonx/2, listtop +listy/2 +15, buttonx, buttony);
    hDwp = windf( hEdit, diredit_l, edittop, edit_w, edity);
    EndDeferWindowPos( hDwp );
}

void winp::setSizePara(LPARAM lp, int nStatus_h, BOOL picflg, int tab, int ListLWidth)
{
	sizelp=lp;
	dir_h = 30;
	if(DirEditMode==_HIDE) dir_h = 0;
	dir_ueh = 0;//5;//dir ̏
	dir_sitah = 0;//5;
	diredit_l =0;
	dir_w =15;
	insideX =LOWORD(lp);
	edit_w =insideX; 
	status_h =nStatus_h;
	insideY =HIWORD(lp) - nStatus_h;//
	listy =insideY -dir_h -dir_ueh -dir_sitah;
	if(videoIn)
	{
		listy =0;
		buttonx=0;
		buttony=0;
		dir_h =0;
	}
	else 
	{
		if(mode==W_MODE_LISTnEDIT) 
		{
			listy /=2;
			listy =max(listy, 100);
		}
		if(mode==W_MODE_EDITONLY) 
		{
			listy =0;
			buttonx=0;
			buttony=0;
			dir_h =0;
		}
		else
		{
			buttonx=22;
			buttony=24;
		}
	}
	if(ButtonMode==_HIDE) { buttonx =0; dir_w =0;}
	if(mode==W_MODE_LIST) ;
	dirR_h =dir_h;
	dirL_h =dir_h;
	listtop =dir_h +dir_ueh +dir_sitah;
	edittop =listtop +listy;
	edity =insideY -listy -listtop;
	xLpercent =ListLWidth;
	xRpercent =100 -xLpercent;
	xL =(float)insideX /100 *xLpercent;
	xR =insideX -xL;
	listLy =listy;
	listRy =listy;
	if(picflg ) 
	{
		ntab =tab;
		if(tab ==tab_r) {listLy =0; dirL_h =0;}
		if(tab ==tab_l) {listRy =0; dirR_h =0;}
		edity =0;
	}
}


void TitleBar(HWND hWnd)
{
	int style = GetWindowLong(hWnd, GWL_STYLE); 
	static BOOL f = ( style == (style | WS_CAPTION) );
    if(f)
	{
		style = (style & ~WS_CAPTION);
		f =FALSE;
	}
	else 
	{
		style = (style | WS_CAPTION);
		f =TRUE;
	}
    SetWindowLong( hWnd, GWL_STYLE, style);
	ShowWindow( hWnd, SW_HIDE);
	ShowWindow( hWnd, SW_SHOW);
}

==> filemv0.483.zip: source/winpaint.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <windows.h>

#include "main.h"
#include "mode.h"
#include "initial.h"
#include "paintflag.h"
#include "winpaint.h"
#include "tab.h"

#define resize() SendMessage(hmainwnd,WM_SIZE,0,0);


void winp::BitBlt(HDC hdc, HDC mem, int wx, int wy)
{
	wx = (wx==0) ? insideX : wx;
	wy = (wy==0) ? insideY : wy;
	pX =0; pY =0;
	pW =wx; pH =wy+status_h;
	memX =0;//oX;
	memY =0;//oY;

	if(ntab ==tab_r || mode==W_MODE_EDITONLY) 
	{
		pX =diredit_l;
	}
	else 
	{
		pX =xL +buttonx/2;
	}
	::BitBlt(hdc, pX,pY,pW,pH, mem, memX, memY, SRCCOPY);
}

void winp::set(HWND dr,HWND dl,HWND der, HWND del, HWND u, HWND d, HWND ed, HWND ta)
{
	hDir =dr;
	hDirL =dl;
	hDirEdit =der;
	hDirEditL =del;
	hUp =u;
	hDown =d;
	hEdit =ed;
	hTab =ta;
}

#define windf(hW, x, y, wx, wy) DeferWindowPos(hDwp, hW, HWND_TOP, x, y, wx, wy, SWP_SHOWWINDOW)

void winp::mvWins()
{
    HDWP hDwp;
    hDwp = BeginDeferWindowPos(9);
    hDwp = windf( hTab, diredit_l, tab_top, edit_w, tab_h );
    hDwp = windf( hDirL, xL -dir_w, dir_ueh, dir_w, dirL_h );
    hDwp = windf( hDir, xL , dir_ueh, dir_w, dirR_h );
    hDwp = windf( hDirEditL, diredit_l, dir_ueh, xL -dir_w, dirL_h);
    hDwp = windf( hDirEdit, xL +dir_w, dir_ueh, xR -dir_w, dirR_h);
    hDwp = windf( hListL, diredit_l, listtop, xL -buttonx/2, listLy);
    hDwp = windf( hList, xL +buttonx/2, listtop, xR - buttonx/2, listRy );
    hDwp = windf( hUp, xL -buttonx/2, listtop +listy/2 -25, buttonx, buttony);
    hDwp = windf( hDown, xL -buttonx/2, listtop +listy/2 +15, buttonx, buttony);
    hDwp = windf( hEdit, diredit_l, edittop, edit_w, edity);
    EndDeferWindowPos( hDwp );
}

void winp::setSizePara(LPARAM lp, int nStatus_h, BOOL picflg, int tab, int ListLWidth)
{
	sizelp=lp;
	dir_h = 30;
	if(DirEditMode==_HIDE) dir_h = 0;
	tab_h =33;
	tab_top =0;
	dir_ueh = tab_h;//5;//dir ̏
	dir_sitah = 0;//5;
	diredit_l =0;
	dir_w =15;
	insideX =LOWORD(lp);
	edit_w =insideX; 
	status_h =nStatus_h;
	insideY =HIWORD(lp) - nStatus_h;//
	listy =insideY -dir_h -dir_ueh -dir_sitah;
	if(videoIn)
	{
		listy =0;
		buttonx=0;
		buttony=0;
		dir_h =0;
		tab_h=0;
	}
	else 
	{
		if(mode==W_MODE_LISTnEDIT) 
		{
			listy /=2;
			listy =max(listy, 100);
		}
		if(mode==W_MODE_EDITONLY) 
		{
			listy =0;
			buttonx=0;
			buttony=0;
			dir_h =0;
			tab_h=0;
		}
		else
		{
			buttonx=22;
			buttony=24;
		}
	}
	if(ButtonMode==_HIDE) { buttonx =0; dir_w =0;}
	if(mode==W_MODE_LIST) ;
	dirR_h =dir_h;
	dirL_h =dir_h;
	listtop =dir_h +dir_ueh +dir_sitah;
	edittop =listtop +listy;
	edity =insideY -listy -listtop;
	xLpercent =ListLWidth;
	xRpercent =100 -xLpercent;
	xL =(float)insideX /100 *xLpercent;
	xR =insideX -xL;
	listLy =listy;
	listRy =listy;
	if(picflg ) 
	{
		ntab =tab;
		if(tab ==tab_r) {listLy =0; dirL_h =0;}
		if(tab ==tab_l) {listRy =0; dirR_h =0;}
		edity =0;
	}
}


void TitleBar(HWND hWnd)
{
	int style = GetWindowLong(hWnd, GWL_STYLE); 
	static BOOL f = ( style == (style | WS_CAPTION) );
    if(f)
	{
		style = (style & ~WS_CAPTION);
		f =FALSE;
	}
	else 
	{
		style = (style | WS_CAPTION);
		f =TRUE;
	}
    SetWindowLong( hWnd, GWL_STYLE, style);
	ShowWindow( hWnd, SW_HIDE);
	ShowWindow( hWnd, SW_SHOW);
}
